@@ -94,16 +94,14 @@ void tangle_box_layout_set_focus_length(TangleBoxLayout* box_layout, gfloat focu
 }
 
 static void calculate_preferred_width(TangleBoxLayout* box_layout, TangleWidget* widget, gfloat for_height) {
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
 
 	if (for_height < 0 || for_height != box_layout->priv->for_height) {
 		box_layout->priv->for_height = for_height;
 		box_layout->priv->interactive_width = box_layout->priv->min_width = box_layout->priv->natural_width = box_layout->priv->shrinkable_width = box_layout->priv->expandable_width = 0;
 		box_layout->priv->expandable_count = 0;
-		for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-			ClutterActor* actor;
-
-			actor = CLUTTER_ACTOR(child_in_list->data);
+		for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 			if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 				TangleBoxLayoutMeta* box_layout_meta;
 				gfloat min_width;
@@ -141,11 +139,13 @@ static void calculate_preferred_width(TangleBoxLayout* box_layout, TangleWidget*
 }
 
 static void allocate_width(TangleBoxLayout* box_layout, TangleWidget* widget, gfloat width) {
-	GList* child_in_list;
 	gfloat interacting_factor;
 	gfloat shrinkable_factor;
 	gfloat fixed_factor;
 	gfloat expandable_factor;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
+	TangleBoxLayoutMeta* box_layout_meta;
 
 	if (width < box_layout->priv->interactive_width) {
 		interacting_factor = width / box_layout->priv->interactive_width;
@@ -190,12 +190,7 @@ static void allocate_width(TangleBoxLayout* box_layout, TangleWidget* widget, gf
 		expandable_factor = 1;
 	}
 
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next)
-	{
-		ClutterActor* actor;
-		TangleBoxLayoutMeta* box_layout_meta;
-
-		actor = child_in_list->data;
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		box_layout_meta = TANGLE_BOX_LAYOUT_META(tangle_layout_get_meta(TANGLE_LAYOUT(box_layout), actor));
 		if (box_layout_meta->priv->interacting) {
 			box_layout_meta->priv->allocated_width = box_layout_meta->priv->requested_width * interacting_factor;
@@ -213,7 +208,8 @@ static void allocate_width(TangleBoxLayout* box_layout, TangleWidget* widget, gf
 }
 
 static void get_preferred_height(TangleBoxLayout* box_layout, TangleWidget* widget, gfloat for_width, gfloat* min_height_p, gfloat* natural_height_p) {
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
 	gfloat min_height;
 	gfloat natural_height;
 
@@ -223,10 +219,7 @@ static void get_preferred_height(TangleBoxLayout* box_layout, TangleWidget* widg
 	}
 	
 	min_height = natural_height = 0;
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-		ClutterActor* actor;
-		
-		actor = child_in_list->data;
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 			TangleBoxLayoutMeta* box_layout_meta;
 			gfloat actor_for_width;
@@ -276,7 +269,8 @@ static void tangle_box_layout_get_preferred_height(TangleLayout* layout, TangleW
 
 static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widget, gfloat width, gfloat height, ClutterAllocationFlags flags) {
 	TangleBoxLayout* box_layout;
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
 	gfloat x;
 	gfloat real_x;
 	
@@ -286,8 +280,7 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 	allocate_width(box_layout, widget, width - box_layout->priv->focus_length);
 	
 	x = real_x = 0;
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-		ClutterActor* actor;
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		TangleBoxLayoutMeta* box_layout_meta;
 		gfloat y;
 		gfloat actor_width;
@@ -295,7 +288,6 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 		gfloat actor_height;
 		ClutterActorBox actor_box;
 		
-		actor = CLUTTER_ACTOR(child_in_list->data);
 		if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 			box_layout_meta = TANGLE_BOX_LAYOUT_META(tangle_layout_get_meta(TANGLE_LAYOUT(box_layout), actor));
 
