@@ -30,11 +30,13 @@ enum {
 	PROP_HIGHLIGHT_COLOR,
 	PROP_HIGHLIGHT_DISTANCE,
 	PROP_HIGHLIGHT_ACTIVATE_DURATION,
-	PROP_HIGHLIGHT_INACTIVATE_DURATION
+	PROP_HIGHLIGHT_INACTIVATE_DURATION,
+	PROP_HOLD_TIMEOUT
 };
 
 enum {
 	CLICKED,
+	HELD,
 	LAST_SIGNAL
 };
 
@@ -46,10 +48,14 @@ struct _TangleButtonPrivate {
 	gfloat highlight_distance;
 	guint highlight_activate_duration;
 	guint highlight_inactivate_duration;
+	guint hold_timeout;
 
-	ClutterActor* button_release_event_handler_actor;
+	ClutterActor* captured_event_handler_actor;
 	ClutterEffect* highlight_effect;
 	ClutterAnimation* highlight_animation;
+	guint timeout_source_id;
+	gfloat start_x;
+	gfloat start_y;
 
 	guint active : 1;
 	guint inside : 1;
@@ -63,7 +69,7 @@ static const GEnumValue button_mode_values[] = {
 	{ 0, NULL, NULL }
 };
 
-static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data);
+static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data);
 static void begin_interacting(TangleButton* button);
 static void end_interacting(TangleButton* button);
 
@@ -347,6 +353,9 @@ static void tangle_button_set_property(GObject* object, guint prop_id, const GVa
 		case PROP_HIGHLIGHT_INACTIVATE_DURATION:
 			button->priv->highlight_inactivate_duration = g_value_get_uint(value);
 			break;
+		case PROP_HOLD_TIMEOUT:
+			button->priv->hold_timeout = g_value_get_uint(value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -388,6 +397,9 @@ static void tangle_button_get_property(GObject* object, guint prop_id, GValue* v
 		case PROP_HIGHLIGHT_INACTIVATE_DURATION:
 			g_value_set_uint(value, button->priv->highlight_inactivate_duration);
 			break;
+		case PROP_HOLD_TIMEOUT:
+			g_value_set_uint(value, button->priv->hold_timeout);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -413,9 +425,9 @@ static void tangle_button_dispose(GObject* object) {
 	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->interactive_background_actor);
 	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->selected_background_actor);
 	
-	if (button->priv->button_release_event_handler_actor) {
-		g_signal_handlers_disconnect_by_func(button->priv->button_release_event_handler_actor, G_CALLBACK(on_button_release_event), button);
-		button->priv->button_release_event_handler_actor = NULL;
+	if (button->priv->captured_event_handler_actor) {
+		g_signal_handlers_disconnect_by_func(button->priv->captured_event_handler_actor, G_CALLBACK(on_captured_event), button);
+		button->priv->captured_event_handler_actor = NULL;
 	}
 
 	G_OBJECT_CLASS(tangle_button_parent_class)->dispose(object);
@@ -527,6 +539,17 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	                                "The duration in milliseconds how long it takes to fade off highlighting after inactivating the button",
 	                                0, G_MAXUINT, 1000,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleButton:hold-timeout:
+	 *
+	 * The duration in milliseconds how long a tap must last to emit held signal. Use 0 to disable the feature.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HOLD_TIMEOUT,
+	                                g_param_spec_uint("hold-timeout",
+	                                "Hold timeout",
+	                                "The duration in milliseconds how long a tap must last to emit held signal",
+	                                0, G_MAXUINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * TangleButton:clicked:
@@ -537,6 +560,15 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 					g_signal_accumulator_true_handled, NULL,
 					tangle_marshal_BOOLEAN__VOID,
 					G_TYPE_BOOLEAN, 0);
+	/**
+	 * TangleButton:held:
+	 * @actor: the object which received the signal
+	 */
+	signals[HELD] = g_signal_new("held", G_TYPE_FROM_CLASS(gobject_class),
+	                                G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET(TangleButtonClass, held),
+					g_signal_accumulator_true_handled, NULL,
+					tangle_marshal_BOOLEAN__VOID,
+					G_TYPE_BOOLEAN, 0);
 
 	g_type_class_add_private(gobject_class, sizeof(TangleButtonPrivate));
 }
@@ -553,10 +585,6 @@ static void start_interacting(TangleButton* button) {
 	button->priv->highlight_animation = tangle_object_animate(G_OBJECT(button->priv->highlight_effect), CLUTTER_LINEAR, button->priv->highlight_activate_duration, "distance", button->priv->highlight_distance, NULL);
 	g_object_add_weak_pointer(G_OBJECT(button->priv->highlight_animation), (gpointer*)&button->priv->highlight_animation);
 	
-	button->priv->button_release_event_handler_actor = clutter_actor_get_stage(CLUTTER_ACTOR(button));
-	g_object_add_weak_pointer(G_OBJECT(button->priv->button_release_event_handler_actor), (gpointer*)&button->priv->button_release_event_handler_actor);
-	g_signal_connect(button->priv->button_release_event_handler_actor, "button-release-event", G_CALLBACK(on_button_release_event), button);
-
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), TRUE);
 }
 
@@ -577,12 +605,9 @@ static void end_interacting(TangleButton* button) {
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
 }
 
-static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
-	TangleButton* button;
+static void button_released(TangleButton* button) {
 	gboolean handled;
 
-	button = TANGLE_BUTTON(user_data);
-
 	if (button->priv->inside) {
 		if (button->priv->mode == TANGLE_BUTTON_SELECTABLE) {
 			button->priv->selected = !button->priv->selected;
@@ -600,19 +625,85 @@ static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event
 		g_signal_emit(button, signals[CLICKED], 0, &handled);
 	}
 
-	if (button->priv->button_release_event_handler_actor) {
-		g_signal_handlers_disconnect_by_func(button->priv->button_release_event_handler_actor, G_CALLBACK(on_button_release_event), button);
-		button->priv->button_release_event_handler_actor = NULL;
+	if (button->priv->captured_event_handler_actor) {
+		g_signal_handlers_disconnect_by_func(button->priv->captured_event_handler_actor, G_CALLBACK(on_captured_event), button);
+		button->priv->captured_event_handler_actor = NULL;
+	}
+}
+
+static gboolean on_timeout(gpointer user_data) {
+	TangleButton* button;
+	gboolean handled;
+	
+	button = TANGLE_BUTTON(user_data);
+	
+	g_signal_emit(button, signals[HELD], 0, &handled);
+
+	end_interacting(button);
+	button->priv->active = FALSE;
+
+	if (button->priv->captured_event_handler_actor) {
+		g_signal_handlers_disconnect_by_func(button->priv->captured_event_handler_actor, G_CALLBACK(on_captured_event), button);
+		button->priv->captured_event_handler_actor = NULL;
 	}
 
 	return FALSE;
 }
 
-static gboolean on_button_press_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
-	start_interacting(TANGLE_BUTTON(actor));
-	TANGLE_BUTTON(actor)->priv->active = TRUE;
-	TANGLE_BUTTON(actor)->priv->inside = TRUE;
+#define ABS_F(x) ((x) < 0 ? -(x) : (x))
+
+static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
+	TangleButton* button;
+	gfloat x, y;
+	gint double_click_distance;
+
+	button = TANGLE_BUTTON(user_data);
 	
+	switch (clutter_event_type(event)) {
+		case CLUTTER_BUTTON_RELEASE:
+			if (clutter_event_get_click_count(event) == 1) {
+				button_released(button);
+				
+				if (button->priv->timeout_source_id) {
+					g_source_remove(button->priv->timeout_source_id);
+					button->priv->timeout_source_id = 0;
+				}
+			}
+			break;
+		case CLUTTER_MOTION:
+			g_object_get(clutter_settings_get_default(), "double-click-distance", &double_click_distance, NULL);
+			clutter_event_get_coords(event, &x, &y);
+			if ((ABS_F(x - button->priv->start_x) > double_click_distance ||
+			     ABS_F(y - button->priv->start_y) > double_click_distance) &&
+			    button->priv->timeout_source_id) {
+				g_source_remove(button->priv->timeout_source_id);
+				button->priv->timeout_source_id = 0;
+			}
+			break;
+	}
+	
+	return FALSE;
+}
+
+static gboolean on_button_press_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
+	TangleButton* button;
+
+	if (clutter_event_get_click_count(event) == 1) {
+		button = TANGLE_BUTTON(actor);
+		start_interacting(button);
+		button->priv->active = TRUE;
+		button->priv->inside = TRUE;
+
+		button->priv->captured_event_handler_actor = clutter_actor_get_stage(CLUTTER_ACTOR(button));
+		g_object_add_weak_pointer(G_OBJECT(button->priv->captured_event_handler_actor), (gpointer*)&button->priv->captured_event_handler_actor);
+		g_signal_connect(button->priv->captured_event_handler_actor, "captured-event", G_CALLBACK(on_captured_event), button);
+
+		if (button->priv->hold_timeout > 0) {
+			clutter_event_get_coords(event, &button->priv->start_x, &button->priv->start_y);
+			button->priv->timeout_source_id = g_timeout_add(button->priv->hold_timeout, on_timeout, button);
+		}
+	}
+
 	return FALSE;
 }
 
