@@ -77,6 +77,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data);
 static gfloat normalise_offset(TangleScrollAction* scroll_action, Axis axis, gfloat offset, gfloat* delta_return);
+static gfloat emit_clamp_offset(TangleScrollAction* scroll_action, Axis axis, gfloat offset);
 static void stop_interacting(TangleScrollAction* scrol_actor);
 static void on_notify_descendant_dragging(GObject* object, GParamSpec* param_spec, gpointer user_data);
 static void on_notify_layout(GObject* object, GParamSpec* param_spec, gpointer user_data);
@@ -269,28 +270,24 @@ void tangle_scroll_action_set_bind_to_scroll_trick(TangleScrollAction* scroll_ac
 
 void tangle_scroll_action_clamp_offset_x(TangleScrollAction* scroll_action) {
 	TangleClamp* clamp;
+	gfloat offset;
 	
 	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
 
-	clamp = tangle_clamp_new(TANGLE_CLAMP_HORIZONTAL, scroll_action->priv->offset[HORIZONTAL]);
-	g_signal_emit(scroll_action, signals[CLAMP_OFFSET_X], 0, clamp);
-	if (tangle_clamp_get_clamped_value_set(clamp)) {
-		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-x", tangle_clamp_get_clamped_value(clamp), NULL);		
+	if ((offset = emit_clamp_offset(scroll_action, HORIZONTAL, scroll_action->priv->offset[HORIZONTAL])) != scroll_action->priv->offset[HORIZONTAL]) {
+		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-x", offset, NULL);		
 	}
-	g_object_unref(clamp);
 }
 
 void tangle_scroll_action_clamp_offset_y(TangleScrollAction* scroll_action) {
 	TangleClamp* clamp;
+	gfloat offset;
 	
 	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
 
-	clamp = tangle_clamp_new(TANGLE_CLAMP_VERTICAL, scroll_action->priv->offset[VERTICAL]);
-	g_signal_emit(scroll_action, signals[CLAMP_OFFSET_Y], 0, clamp);
-	if (tangle_clamp_get_clamped_value_set(clamp)) {
-		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", tangle_clamp_get_clamped_value(clamp), NULL);		
+	if ((offset = emit_clamp_offset(scroll_action, VERTICAL, scroll_action->priv->offset[VERTICAL])) != scroll_action->priv->offset[VERTICAL]) {
+		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", offset, NULL);		
 	}
-	g_object_unref(clamp);
 }
 
 void tangle_scroll_action_clamp_offsets(TangleScrollAction* scroll_action) {
@@ -722,8 +719,8 @@ static void handle_event(TangleScrollAction* scroll_action, ClutterActor* actor,
 	gfloat d;
 	gdouble v, a;
 	guint t;
-	TangleClamp* clamp;
 	gfloat delta = 0.0;
+	gfloat offset, clamped_offset;
 
 	backend = clutter_get_default_backend();
 	d = coordinate - scroll_action->priv->start_scrolling_motion[axis];
@@ -774,16 +771,12 @@ static void handle_event(TangleScrollAction* scroll_action, ClutterActor* actor,
 		    event_time - scroll_action->priv->previous_motion_time < clutter_backend_get_double_click_time(backend)) {
 			if (event_time - scroll_action->priv->start_motion_time[axis] > 0) {
 				v = (gdouble)(coordinate - scroll_action->priv->start_motion[axis]) / (event_time - scroll_action->priv->start_motion_time[axis]);
-
-				clamp = tangle_clamp_new((axis == HORIZONTAL ? TANGLE_CLAMP_HORIZONTAL : TANGLE_CLAMP_VERTICAL), normalise_offset(scroll_action, axis, scroll_action->priv->offset[axis] + (scroll_action->priv->going_forward[axis] ? -1 : 1) * v * v * 1000 / scroll_action->priv->deceleration / 2, &delta));
-				g_signal_emit(scroll_action, signals[(axis == HORIZONTAL ? CLAMP_OFFSET_X : CLAMP_OFFSET_Y)], 0, clamp);
-				if (tangle_clamp_get_clamped_value_set(clamp)) {
-					a = v * v * 1000 / ABS_F(tangle_clamp_get_clamped_value(clamp) - scroll_action->priv->offset[axis] + delta) / 2;
+				offset = normalise_offset(scroll_action, axis, scroll_action->priv->offset[axis] + (scroll_action->priv->going_forward[axis] ? -1 : 1) * v * v * 1000 / scroll_action->priv->deceleration / 2, &delta);
+				if ((clamped_offset = emit_clamp_offset(scroll_action, axis, offset)) != offset) {
+					a = v * v * 1000 / ABS_F(clamped_offset - scroll_action->priv->offset[axis]) / 2;
 				} else {
 					a = scroll_action->priv->deceleration;
-
 				}
-				g_object_unref(clamp);
 
 				t = ABS_F(v * 1000.0 / a);
 
@@ -904,6 +897,30 @@ static gfloat normalise_offset(TangleScrollAction* scroll_action, Axis axis, gfl
 	return offset;
 }
 
+static gfloat emit_clamp_offset(TangleScrollAction* scroll_action, Axis axis, gfloat offset) {
+	TangleClamp* clamp;
+	gfloat offset_adjustment = 0.0;
+	
+	if (offset < 0.0) {
+		offset_adjustment = scroll_action->priv->max_offset[axis];
+		offset += offset_adjustment;
+	} else if (offset > scroll_action->priv->max_offset[axis]) {
+		offset_adjustment = -scroll_action->priv->max_offset[axis];
+		offset += offset_adjustment;
+	}
+
+	clamp = tangle_clamp_new((axis == HORIZONTAL ? TANGLE_CLAMP_HORIZONTAL : TANGLE_CLAMP_VERTICAL), offset);
+	g_signal_emit(scroll_action, signals[(axis == HORIZONTAL ? CLAMP_OFFSET_X : CLAMP_OFFSET_Y)], 0, clamp);
+	if (tangle_clamp_get_clamped_value_set(clamp)) {
+		offset = tangle_clamp_get_clamped_value(clamp);
+	}
+	g_object_unref(clamp);
+
+	offset -= offset_adjustment;
+
+	return offset;
+}
+
 static void stop_interacting(TangleScrollAction* scroll_action) {
 	ClutterActor* actor;
 	
