@@ -33,6 +33,8 @@ GType tangle_stylable_get_type(void) {
 gboolean tangle_stylable_apply_stylesheet(TangleStylable* stylable, TangleStylesheet* stylesheet) {
 	gboolean handled = FALSE;
 	TangleStylableIface* stylable_iface;
+
+	g_return_val_if_fail(TANGLE_IS_STYLABLE(stylable), FALSE);
 	
 	stylable_iface = TANGLE_STYLABLE_GET_IFACE(stylable);
 	if (stylable_iface->apply_stylesheet) {
@@ -46,6 +48,8 @@ gboolean tangle_stylable_unapply_stylesheet(TangleStylable* stylable, TangleStyl
 	gboolean handled = FALSE;
 	TangleStylableIface* stylable_iface;
 	
+	g_return_val_if_fail(TANGLE_IS_STYLABLE(stylable), FALSE);
+	
 	stylable_iface = TANGLE_STYLABLE_GET_IFACE(stylable);
 	if (stylable_iface->unapply_stylesheet) {
 		handled = stylable_iface->unapply_stylesheet(stylable, stylesheet);
@@ -58,6 +62,8 @@ gboolean tangle_stylable_set_style_property(TangleStylable* stylable, const gcha
 	gboolean handled = FALSE;
 	TangleStylableIface* stylable_iface;
 	
+	g_return_val_if_fail(TANGLE_IS_STYLABLE(stylable), FALSE);
+	
 	stylable_iface = TANGLE_STYLABLE_GET_IFACE(stylable);
 	if (stylable_iface->set_style_property) {
 		handled = stylable_iface->set_style_property(stylable, name, value);
@@ -71,6 +77,8 @@ gboolean tangle_stylable_unset_style_property(TangleStylable* stylable, const gc
 	TangleStylableIface* stylable_iface;
 	
 	stylable_iface = TANGLE_STYLABLE_GET_IFACE(stylable);
+	g_return_val_if_fail(TANGLE_IS_STYLABLE(stylable), FALSE);
+	
 	if (stylable_iface->unset_style_property) {
 		handled = stylable_iface->unset_style_property(stylable, name, value);
 	}
@@ -82,6 +90,8 @@ gboolean tangle_stylable_is_style_property(TangleStylable* stylable, const gchar
 	gboolean retvalue;
 	TangleStylableIface* stylable_iface;
 	
+	g_return_val_if_fail(TANGLE_IS_STYLABLE(stylable), FALSE);
+	
 	stylable_iface = TANGLE_STYLABLE_GET_IFACE(stylable);
 	if (stylable_iface->is_style_property) {
 		retvalue = stylable_iface->is_style_property(stylable, name, value);
@@ -97,6 +107,8 @@ gboolean tangle_object_has_property_value(GObject* object, const gchar* name, GV
 	GParamSpec* param_spec;
 	GValue current_value = { 0 };
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), FALSE);
+	
 	param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name);
 	g_object_get_property(object, name, &current_value);
 	if (!g_param_values_cmp(param_spec, &current_value, value)) {
