@@ -11,7 +11,6 @@
 #include "tangle-properties.h"
 #include "tangle-stylable.h"
 #include "tangle-template.h"
-#include "tangle-action.h"
 #include "tangle-vault.h"
 #include "tangle-misc.h"
 #include "marshalers.h"
@@ -75,32 +74,40 @@ TangleStyle* tangle_style_new(GType for_type) {
 }
 
 GType tangle_style_get_for_type(TangleStyle* style) {
-
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), G_TYPE_NONE);
+	
 	return style->priv->for_type;
 }
 
 const gchar* tangle_style_get_for_class(TangleStyle* style) {
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), NULL);
 
 	return g_type_name(style->priv->for_type);
 }
 
 const gchar* tangle_style_get_for_name(TangleStyle* style) {
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), NULL);
 
 	return style->priv->for_name;
 }
 
 void tangle_style_set_for_name(TangleStyle* style, const gchar* for_name) {
+	g_return_if_fail(TANGLE_IS_STYLE(style));
+
 	g_free(style->priv->for_name);
 	style->priv->for_name = g_strdup(for_name);
 	g_object_notify(G_OBJECT(style), "for-name");
 }
 
 gboolean tangle_style_get_for_subclasses(TangleStyle* style) {
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), FALSE);
 
 	return style->priv->for_subclasses;
 }
 
 void tangle_style_set_for_subclasses(TangleStyle* style, gboolean for_subclasses) {
+	g_return_if_fail(TANGLE_IS_STYLE(style));
+
 	if (style->priv->for_subclasses != for_subclasses) {
 		style->priv->for_subclasses = for_subclasses;
 		g_object_notify(G_OBJECT(style), "for-subclasses");
@@ -108,21 +115,25 @@ void tangle_style_set_for_subclasses(TangleStyle* style, gboolean for_subclasses
 }
 
 gboolean tangle_style_get_style_property(TangleStyle* style, const gchar* name, GValue* value) {
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), FALSE);
 
 	return TANGLE_STYLE_GET_CLASS(style)->get_style_property(style, name, value);
 }
 
 void tangle_style_set_style_property(TangleStyle* style, const gchar* name, const GValue* value) {
+	g_return_if_fail(TANGLE_IS_STYLE(style));
 
 	return TANGLE_STYLE_GET_CLASS(style)->set_style_property(style, name, value);
 }
 
 void tangle_style_foreach_style_property(TangleStyle* style, TanglePropertyCallback callback, gpointer user_data) {
+	g_return_if_fail(TANGLE_IS_STYLE(style));
 
 	return TANGLE_STYLE_GET_CLASS(style)->foreach_style_property(style, callback, user_data);
 }
 
 gboolean tangle_style_is_for_object(TangleStyle* style, GObject* object) {
+	g_return_val_if_fail(TANGLE_IS_STYLE(style), FALSE);
 	
 	return ((style->priv->for_subclasses && g_type_is_a(G_OBJECT_TYPE(object), style->priv->for_type)) ||
 	        (!style->priv->for_subclasses && G_OBJECT_TYPE(object) == style->priv->for_type)) &&
@@ -136,6 +147,8 @@ void tangle_style_apply(TangleStyle* style, GObject* object) {
 	TangleStyle* old_style;
 	GHashTable* hash_table;
 
+	g_return_if_fail(TANGLE_IS_STYLE(style));
+
 	old_style = TANGLE_STYLE(g_object_get_qdata(object, quark_object_style));
 	if (old_style != style) {
 		g_object_ref(style);
@@ -161,6 +174,8 @@ void tangle_style_unapply(TangleStyle* style, GObject* object) {
 	TangleStyle* old_style;
 	GHashTable* hash_table;
 	
+	g_return_if_fail(TANGLE_IS_STYLE(style));
+
 	old_style = TANGLE_STYLE(g_object_get_qdata(object, quark_object_style));
 	if (old_style == style) {
 		tangle_style_foreach_style_property(style, unset_style_property, object);
@@ -180,6 +195,7 @@ void tangle_style_unapply(TangleStyle* style, GObject* object) {
 }
 
 TangleStyle* tangle_object_get_style(GObject* object) {
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
 	
 	return TANGLE_STYLE(g_object_get_qdata(object, quark_object_style));
 }
@@ -188,6 +204,8 @@ gboolean tangle_object_is_style_property(GObject* object, const gchar* name) {
 	gboolean retvalue = FALSE;
 	GHashTable* hash_table;
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), FALSE);
+
 	hash_table = (GHashTable*)g_object_get_qdata(object, quark_object_style_properties);
 	if (hash_table) {
 		retvalue = g_hash_table_lookup_extended(hash_table, name, NULL, NULL);
@@ -434,9 +452,7 @@ static void set_style_property(const gchar* name, const GValue* value, gpointer
 	}
 	if (!handled &&
 	    (hash_table = (GHashTable*)g_object_get_qdata(object, quark_object_style_properties))) {
-	    	if (G_VALUE_HOLDS(value, TANGLE_TYPE_ACTION)) {
-			tangle_action_add(TANGLE_ACTION(g_value_get_object(value)), object, name);
-		} else if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
+	    	if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
 			g_value_init(&current_value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
 			g_object_get_property(object, name, &current_value);
 			if (g_param_value_defaults(param_spec, &current_value)) {
@@ -467,9 +483,7 @@ static void unset_style_property(const gchar* name, const GValue* value, gpointe
 	    (hash_table = (GHashTable*)g_object_get_qdata(object, quark_object_style_properties)) &&
 	    g_hash_table_remove(hash_table, name)) {
 		BLOCK_NOTIFY_HANDLER(object, hash_table);
-		if (G_VALUE_HOLDS(value, TANGLE_TYPE_ACTION)) {
-			tangle_action_remove(TANGLE_ACTION(g_value_get_object(value)), object, name);		
-		} else if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
+		if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
 			g_value_init(&current_value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
 			g_param_value_set_default(param_spec, &current_value);
 			set_object_property(object, name, G_PARAM_SPEC_VALUE_TYPE(param_spec), &current_value);
@@ -494,10 +508,7 @@ static void change_style_property(GObject* object, const gchar* name, const GVal
 	    (hash_table = (GHashTable*)g_object_get_qdata(object, quark_object_style_properties)) &&
 	    g_hash_table_lookup_extended(hash_table, name, NULL, NULL)) {
 		BLOCK_NOTIFY_HANDLER(object, hash_table);
-		if (G_VALUE_HOLDS(old_value, TANGLE_TYPE_ACTION)) {
-			tangle_action_remove(TANGLE_ACTION(g_value_get_object(old_value)), object, name);
-			tangle_action_add(TANGLE_ACTION(g_value_get_object(new_value)), object, name);
-		} else if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
+		if (param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(object), name)) {
 			set_object_property(object, name, G_PARAM_SPEC_VALUE_TYPE(param_spec), new_value);
 		} else {
 			g_warning("%s: object does not have property called '%s'.", G_STRLOC, name);
@@ -538,7 +549,6 @@ static void set_object_property(GObject* object, const gchar* name, GType type,
 	TangleTemplate* template;
 	GObject* value_object;
 	GValue object_value = { 0 };
-	TangleAction* action;
 	
 	if (G_VALUE_HOLDS(value, TANGLE_TYPE_TEMPLATE) && !g_type_is_a(type, TANGLE_TYPE_TEMPLATE)) {
 		template = TANGLE_TEMPLATE(g_value_get_object(value));
