@@ -17,14 +17,11 @@
 
 G_DEFINE_ABSTRACT_TYPE(TangleTransition, tangle_transition, G_TYPE_OBJECT);
 
-TangleTransition* tangle_transition_new() {
-
-	return TANGLE_TRANSITION(g_object_new(TANGLE_TYPE_TRANSITION, NULL));
-}
-
 ClutterTimeline* tangle_transition_animate_actor(TangleTransition* transition, TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box) {
 	ClutterTimeline* timeline = NULL;
 	TangleTransitionClass* transition_class;
+
+	g_return_val_if_fail(TANGLE_IS_TRANSITION(transition), NULL);
 	
 	transition_class = TANGLE_TRANSITION_GET_CLASS(transition);
 	if (transition_class->animate_actor) {
