@@ -40,8 +40,6 @@ void tangle_view_set_filename(TangleView* view, const gchar* filename);
 const gchar* tangle_view_get_filename(TangleView* view);
 
 void tangle_view_load_now(TangleView* view);
-
-void tangle_view_start_timelines(TangleView* view);
-void tangle_view_stop_timelines(TangleView* view);
+void tangle_view_unload(TangleView* view);
 
 #endif
