@@ -7,6 +7,10 @@ static void on_clicked(TangleButton* button, gpointer user_data) {
 	g_printf("clicked %s\n", (tangle_button_get_selected(button) ? "(selected)" : ""));
 }
 
+static void on_held(TangleButton* button, gpointer user_data) {
+	g_printf("held\n");
+}
+
 static void on_notify_selected(GObject* object, GParamSpec* param_spec, gpointer user_data) {
 	g_printf("selected %p\n", tangle_button_group_get_selected_button(TANGLE_BUTTON_GROUP(object)));
 }
@@ -36,8 +40,9 @@ int main(int argc, char** argv) {
 
 	clickable_button = tangle_button_new_with_background_actors(normal_texture, active_texture);
 	clutter_actor_set_position(clickable_button, 100.0, 100.0);
-	g_object_set(clickable_button, "highlight-color", &red, "highlight-distance", 20.0, "highlight-activate-duration", 2000, "highlight-inactivate-duration", 4000, NULL);
+	g_object_set(clickable_button, "highlight-color", &red, "highlight-distance", 20.0, "highlight-activate-duration", 2000, "highlight-inactivate-duration", 4000, "hold-timeout", 1500, NULL);
 	g_signal_connect(clickable_button, "clicked", G_CALLBACK(on_clicked), NULL);
+	g_signal_connect(clickable_button, "held", G_CALLBACK(on_held), NULL);
 
 	/* Selectable button */
 
@@ -48,7 +53,9 @@ int main(int argc, char** argv) {
 	selectable_button = tangle_button_new_selectable_with_background_actors(normal_texture, active_texture, selected_texture);
 	tangle_button_set_selected(TANGLE_BUTTON(selectable_button), TRUE);
 	clutter_actor_set_position(selectable_button, 100.0, 300.0);
+	g_object_set(selectable_button, "hold-timeout", 1500, NULL);
 	g_signal_connect(selectable_button, "clicked", G_CALLBACK(on_clicked), NULL);
+	g_signal_connect(selectable_button, "held", G_CALLBACK(on_held), NULL);
 
 	/* Radio button alone */
 
@@ -58,7 +65,9 @@ int main(int argc, char** argv) {
 
 	radio_button = tangle_button_new_radio_with_background_actors(normal_texture, active_texture, selected_texture);
 	clutter_actor_set_position(radio_button, 300.0, 300.0);
+	g_object_set(radio_button, "hold-timeout", 1500, NULL);
 	g_signal_connect(radio_button, "clicked", G_CALLBACK(on_clicked), NULL);
+	g_signal_connect(radio_button, "held", G_CALLBACK(on_held), NULL);
 	
 	/* Radio buttons for a group */
 	
