@@ -16,7 +16,7 @@ int main(int argc, char** argv) {
 	g_object_set(G_OBJECT(stage), "width", 800.0, "height", 480.0, NULL);
 	clutter_stage_set_color(CLUTTER_STAGE(stage), &stage_color);
 
-	actor = clutter_texture_new_from_file("test_image_alpha_150x111.png", NULL);
+	actor = tangle_texture_new("test_image_alpha_150x111.png");
 	clutter_actor_set_position(actor, 100.0, 100.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(stage), actor);
 
