@@ -4,7 +4,6 @@
 #include "tangle/tangle-box-layout.h"
 #include "tangle/tangle-template.h"
 #include "tangle/tangle-stylesheet.h"
-#include "tangle/tangle-set-property-action.h"
 #include <math.h>
 
 
@@ -24,7 +23,6 @@ int main(int argc, char** argv) {
 	ClutterActor* text;
 	gchar* s;
 	TangleSpacing spacing;
-	TangleAction* action;
 	
 	clutter_init(&argc, &argv);
 	
@@ -47,18 +45,6 @@ int main(int argc, char** argv) {
 	tangle_style_set_style_property(style, "background-actor", &value);
 	g_value_unset(&value);
 	
-	action = tangle_set_property_action_new();
-	tangle_set_property_action_set_name(TANGLE_SET_PROPERTY_ACTION(action), "opacity");
-	g_value_init(&value, G_TYPE_UCHAR);
-	g_value_set_uchar(&value, 10);
-	tangle_set_property_action_set_value(TANGLE_SET_PROPERTY_ACTION(action), &value);
-	g_value_unset(&value);
-	
-	g_value_init(&value, TANGLE_TYPE_ACTION);
-	g_value_set_object(&value, action);
-	tangle_style_set_style_property(style, "button-press-action", &value);
-	g_value_unset(&value);
-	
 	stylesheet = tangle_stylesheet_new();
 	tangle_stylesheet_add_style(stylesheet, style);
 
