@@ -10,7 +10,7 @@ int main(int argc, char** argv) {
 	stage = clutter_stage_get_default();
 	clutter_actor_set_size(stage, 800.0, 400.0);
 
-	texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
+	texture = tangle_texture_new("test_image_135x100.jpg");
 	g_assert(texture != NULL);
 	clutter_container_add_actor(CLUTTER_CONTAINER(stage), texture);
 
